package eCommerce;

import java.sql.SQLException;

import javax.faces.bean.ManagedBean;

//manages the creating and updating of customers
//keeps the personal details and billing info of customers
@ManagedBean
public class Customer {
	
	//UI
	private String shipURL = "shipping.jsf";
	private String checkoutURL = "details.jsf";
	private String orderHistoryURL = "orderHistory.jsf";
	private String signInURL = "signin.jsf";
	private boolean signedIn = false;
	private String errMessage = "";
	public String getErrMessage() {
		return errMessage;
	}

	//properties
	private int custNum = 0;
	private String password = "";
	private String passwordConfirm = "";
	private boolean gender = false; //1 if male
    private String firstName = "";
	private String lastName = "";
	private String telephoneNumber = "";
	private String altTelephoneNumber = "";
	private String faxNumber = "";
	
    //billing: must match credit card info
    private String billAddress1 = "";
    private String billAddress2 = "";
    private String billCommunity = "";
    private String billStateProv = "";
    private String billPostCode = "";
    private String billCountry = "";
	
	//setters and getters
	public boolean isGender() {
		return gender;
	}
	public void setGender(boolean gender) {
		this.gender = gender;
	}
	public String getPassword() {
		return password;
	}
	public void setPassword(String password) {
		if (password != "")
		this.password = password;
	}
	public String getFirstName() {
		return firstName;
	}
	public void setFirstName(String firstName) {
		this.firstName = firstName;
	}
	public String getLastName() {
		return lastName;
	}
	public void setLastName(String lastName) {
		this.lastName = lastName;
	}
	public String getTelephoneNumber() {
		return telephoneNumber;
	}
	public void setTelephoneNumber(String telephoneNumber) {
		this.telephoneNumber = telephoneNumber;
	}
	public String getAltTelephoneNumber() {
		return altTelephoneNumber;
	}
	public void setAltTelephoneNumber(String altTelephoneNumber) {
		this.altTelephoneNumber = altTelephoneNumber;
	}
	public String getFaxNumber() {
		return faxNumber;
	}
	public void setFaxNumber(String faxNumber) {
		this.faxNumber = faxNumber;
	}
	public String getPasswordConfirm() {
		return passwordConfirm;
	}
	public void setPasswordConfirm(String passwordConfirm) {
		if (passwordConfirm != "")
		this.passwordConfirm = passwordConfirm;
	}
	public String getBillAddress1() {
		return billAddress1;
	}

	public void setBillAddress1(String billAddress1) {
		this.billAddress1 = billAddress1;
	}

	public String getBillAddress2() {
		return billAddress2;
	}

	public void setBillAddress2(String billAddress2) {
		this.billAddress2 = billAddress2;
	}

	public String getBillCommunity() {
		return billCommunity;
	}

	public void setBillCommunity(String billCommunity) {
		this.billCommunity = billCommunity;
	}

	public String getBillStateProv() {
		return billStateProv;
	}

	public void setBillStateProv(String billStateProv) {
		this.billStateProv = billStateProv;
	}

	public String getBillPostCode() {
		return billPostCode;
	}

	public void setBillPostCode(String billPostCode) {
		this.billPostCode = billPostCode;
	}

	public String getBillCountry() {
		return billCountry;
	}

	public void setBillCountry(String billCountry) {
		this.billCountry = billCountry;
	}
	
	public int getCustNum() {
		return custNum;
	}
	public void setCustNum(int custNum) {
		this.custNum = custNum;
	}
	
	public String signIn(){
		return signInURL;
	}
	
	public void setGender(int int1) {
		if (int1 == 1)
			this.gender = true;
		else
			this.gender = false;
	}
	
	//validate customer details before shipping
	public String goShip(){
		if (this.firstName == "" || this.lastName == "")
		{
			errMessage = "You must enter first and last names.";
			return checkoutURL;
		}
		if (this.billAddress1 == "")
		{
			errMessage = "You must enter an address.";
			return checkoutURL;
		}
		if (this.billCommunity == "")
		{
			errMessage = "You must enter a community.";
			return checkoutURL;
		}
		if (this.billCountry == "")
		{
			errMessage = "You must enter a country.";
			return checkoutURL;
		}
		if (this.telephoneNumber == "")
		{
			errMessage = "You must enter a telephone number.";
			return checkoutURL;
		}
		if (!this.password.equals(this.passwordConfirm))
		{
			errMessage = "Password and confirmation did not match.";
			return checkoutURL;
		}
		
		//having passed all this, let's save the record to the database
		//(for new customers)
		DataAccess myAccess = new DataAccess();
		try {
			if (this.signedIn)
				myAccess.updateCustomer(this);			
			else
				this.custNum = myAccess.saveCustomer(this);
				
		} catch (SQLException e) {
			e.printStackTrace();
		}
		
		return shipURL;
	}
	
	//validate a customer sign in and assign db record to session customer
	public String signInVfy(){
		DataAccess myAccess = new DataAccess();
		Customer custIn = null;
		try {
			custIn = myAccess.verifyCustomer(custNum,password);
		} catch (SQLException e) {
			e.printStackTrace();
		}
		if (custIn != null)
		{
		   this.altTelephoneNumber = custIn.altTelephoneNumber;
		   this.billAddress1 = custIn.billAddress1;
		   this.billAddress2 = custIn.billAddress2;
		   this.billCommunity = custIn.billCommunity;
		   this.billCountry = custIn.billCountry;
		   this.billPostCode = custIn.billPostCode;
		   this.billStateProv = custIn.billStateProv;
		   this.custNum = custIn.custNum;
		   this.faxNumber = custIn.faxNumber;
		   this.firstName = custIn.firstName;
		   this.gender = custIn.gender;
		   this.lastName = custIn.lastName;
		   this.signedIn = true;
		   this.passwordConfirm = this.password;
		   this.telephoneNumber = custIn.telephoneNumber;
		   return orderHistoryURL;
		}
		else
		{
		   errMessage = "Login invalid.";
		   return signInURL;
		}
	}

	
}
